@@ -274,7 +274,7 @@ def fix_version_in_endpoint(api_name, instance):
         url += '/v%s' % instance._api_version[api_name]
 
     # nova & cinder contain project_id in url :(
-    if api_name in ['compute', 'volume']:
+    if api_name in ['compute', 'volume'] and instance._project_id not in url:
         url = url + '/' + instance._project_id
     # version info is in url
     return url
